You are viewing a plain text version of this content. The canonical link for it is here.
Posted to muse-dev@ws.apache.org by sc...@apache.org on 2005/05/31 16:29:44 UTC

svn commit: r179217 [2/2] - in /incubator/muse/trunk/src/ieeedemo: ./ lib/ src/.xmlbeans/src/org/wsdmdemo/service/weatherClientConfig/ src/.xmlbeans/src/org/wsdmdemo/service/weatherClientConfig/impl/ src/.xmlbeans/src/org/wsdmdemo/service/weatherStation/ src/.xmlbeans/src/org/wsdmdemo/service/weatherStation/impl/ src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/ src/java/org/wsdmdemo/service/weatherClientConfig/ src/java/org/wsdmdemo/service/weatherStation/

Modified: incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStation/impl/PriceDocumentImpl.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStation/impl/PriceDocumentImpl.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStation/impl/WeatherStationResourcePropertiesDocumentImpl.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStation/impl/WeatherStationResourcePropertiesDocumentImpl.java Tue May 31 07:29:42 2005
@@ -86,83 +86,241 @@
             super(sType);
         }
         
-        private static final javax.xml.namespace.QName PRICE$0 = 
+        private static final javax.xml.namespace.QName NAME$0 = 
+            new javax.xml.namespace.QName("http://wsdmdemo.org/service/weather-station", "Name");
+        private static final javax.xml.namespace.QName OWNER$2 = 
+            new javax.xml.namespace.QName("http://wsdmdemo.org/service/weather-station", "Owner");
+        private static final javax.xml.namespace.QName PRICE$4 = 
             new javax.xml.namespace.QName("http://wsdmdemo.org/service/weather-station", "Price");
-        private static final javax.xml.namespace.QName TEMPERATURE$2 = 
+        private static final javax.xml.namespace.QName TEMPERATURE$6 = 
             new javax.xml.namespace.QName("http://wsdmdemo.org/service/weather-station", "Temperature");
-        private static final javax.xml.namespace.QName HUMIDITY$4 = 
+        private static final javax.xml.namespace.QName HUMIDITY$8 = 
             new javax.xml.namespace.QName("http://wsdmdemo.org/service/weather-station", "Humidity");
-        private static final javax.xml.namespace.QName VISIBILITY$6 = 
+        private static final javax.xml.namespace.QName VISIBILITY$10 = 
             new javax.xml.namespace.QName("http://wsdmdemo.org/service/weather-station", "Visibility");
-        private static final javax.xml.namespace.QName TOPIC$8 = 
+        private static final javax.xml.namespace.QName TOPIC$12 = 
             new javax.xml.namespace.QName("http://docs.oasis-open.org/wsn/2004/06/wsn-WS-BaseNotification-1.2-draft-01.xsd", "Topic");
-        private static final javax.xml.namespace.QName FIXEDTOPICSET$10 = 
+        private static final javax.xml.namespace.QName FIXEDTOPICSET$14 = 
             new javax.xml.namespace.QName("http://docs.oasis-open.org/wsn/2004/06/wsn-WS-BaseNotification-1.2-draft-01.xsd", "FixedTopicSet");
-        private static final javax.xml.namespace.QName TOPICEXPRESSIONDIALECTS$12 = 
+        private static final javax.xml.namespace.QName TOPICEXPRESSIONDIALECTS$16 = 
             new javax.xml.namespace.QName("http://docs.oasis-open.org/wsn/2004/06/wsn-WS-BaseNotification-1.2-draft-01.xsd", "TopicExpressionDialects");
-        private static final javax.xml.namespace.QName RESOURCEID$14 = 
+        private static final javax.xml.namespace.QName RESOURCEID$18 = 
             new javax.xml.namespace.QName("http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part1.xsd", "ResourceId");
-        private static final javax.xml.namespace.QName MANAGEABILITYCAPABILITY$16 = 
+        private static final javax.xml.namespace.QName MANAGEABILITYCAPABILITY$20 = 
             new javax.xml.namespace.QName("http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part1.xsd", "ManageabilityCapability");
-        private static final javax.xml.namespace.QName CURRENTTIME$18 = 
+        private static final javax.xml.namespace.QName CURRENTTIME$22 = 
             new javax.xml.namespace.QName("http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd", "CurrentTime");
-        private static final javax.xml.namespace.QName OPERATIONALSTATUS$20 = 
+        private static final javax.xml.namespace.QName OPERATIONALSTATUS$24 = 
             new javax.xml.namespace.QName("http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd", "OperationalStatus");
-        private static final javax.xml.namespace.QName RELATIONSHIP$22 = 
+        private static final javax.xml.namespace.QName RELATIONSHIP$26 = 
             new javax.xml.namespace.QName("http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd", "Relationship");
         
         
         /**
-         * Gets the "Price" element
+         * Gets the "Name" element
          */
-        public org.wsdmdemo.service.weatherStation.PriceMetricType getPrice()
+        public java.lang.String getName()
         {
             synchronized (monitor())
             {
                 check_orphaned();
-                org.wsdmdemo.service.weatherStation.PriceMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.PriceMetricType)get_store().find_element_user(PRICE$0, 0);
+                org.apache.xmlbeans.SimpleValue target = null;
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(NAME$0, 0);
                 if (target == null)
                 {
                     return null;
                 }
+                return target.getStringValue();
+            }
+        }
+        
+        /**
+         * Gets (as xml) the "Name" element
+         */
+        public org.apache.xmlbeans.XmlString xgetName()
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                org.apache.xmlbeans.XmlString target = null;
+                target = (org.apache.xmlbeans.XmlString)get_store().find_element_user(NAME$0, 0);
                 return target;
             }
         }
         
         /**
-         * Sets the "Price" element
+         * Sets the "Name" element
          */
-        public void setPrice(org.wsdmdemo.service.weatherStation.PriceMetricType price)
+        public void setName(java.lang.String name)
         {
             synchronized (monitor())
             {
                 check_orphaned();
-                org.wsdmdemo.service.weatherStation.PriceMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.PriceMetricType)get_store().find_element_user(PRICE$0, 0);
+                org.apache.xmlbeans.SimpleValue target = null;
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(NAME$0, 0);
                 if (target == null)
                 {
-                    target = (org.wsdmdemo.service.weatherStation.PriceMetricType)get_store().add_element_user(PRICE$0);
+                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(NAME$0);
                 }
-                target.set(price);
+                target.setStringValue(name);
+            }
+        }
+        
+        /**
+         * Sets (as xml) the "Name" element
+         */
+        public void xsetName(org.apache.xmlbeans.XmlString name)
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                org.apache.xmlbeans.XmlString target = null;
+                target = (org.apache.xmlbeans.XmlString)get_store().find_element_user(NAME$0, 0);
+                if (target == null)
+                {
+                    target = (org.apache.xmlbeans.XmlString)get_store().add_element_user(NAME$0);
+                }
+                target.set(name);
+            }
+        }
+        
+        /**
+         * Gets the "Owner" element
+         */
+        public java.lang.String getOwner()
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                org.apache.xmlbeans.SimpleValue target = null;
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(OWNER$2, 0);
+                if (target == null)
+                {
+                    return null;
+                }
+                return target.getStringValue();
+            }
+        }
+        
+        /**
+         * Gets (as xml) the "Owner" element
+         */
+        public org.apache.xmlbeans.XmlString xgetOwner()
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                org.apache.xmlbeans.XmlString target = null;
+                target = (org.apache.xmlbeans.XmlString)get_store().find_element_user(OWNER$2, 0);
+                return target;
+            }
+        }
+        
+        /**
+         * Sets the "Owner" element
+         */
+        public void setOwner(java.lang.String owner)
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                org.apache.xmlbeans.SimpleValue target = null;
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(OWNER$2, 0);
+                if (target == null)
+                {
+                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(OWNER$2);
+                }
+                target.setStringValue(owner);
+            }
+        }
+        
+        /**
+         * Sets (as xml) the "Owner" element
+         */
+        public void xsetOwner(org.apache.xmlbeans.XmlString owner)
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                org.apache.xmlbeans.XmlString target = null;
+                target = (org.apache.xmlbeans.XmlString)get_store().find_element_user(OWNER$2, 0);
+                if (target == null)
+                {
+                    target = (org.apache.xmlbeans.XmlString)get_store().add_element_user(OWNER$2);
+                }
+                target.set(owner);
             }
         }
         
         /**
-         * Appends and returns a new empty "Price" element
+         * Gets the "Price" element
          */
-        public org.wsdmdemo.service.weatherStation.PriceMetricType addNewPrice()
+        public double getPrice()
         {
             synchronized (monitor())
             {
                 check_orphaned();
-                org.wsdmdemo.service.weatherStation.PriceMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.PriceMetricType)get_store().add_element_user(PRICE$0);
+                org.apache.xmlbeans.SimpleValue target = null;
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(PRICE$4, 0);
+                if (target == null)
+                {
+                    return 0.0;
+                }
+                return target.getDoubleValue();
+            }
+        }
+        
+        /**
+         * Gets (as xml) the "Price" element
+         */
+        public org.apache.xmlbeans.XmlDouble xgetPrice()
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                org.apache.xmlbeans.XmlDouble target = null;
+                target = (org.apache.xmlbeans.XmlDouble)get_store().find_element_user(PRICE$4, 0);
                 return target;
             }
         }
         
         /**
+         * Sets the "Price" element
+         */
+        public void setPrice(double price)
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                org.apache.xmlbeans.SimpleValue target = null;
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(PRICE$4, 0);
+                if (target == null)
+                {
+                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(PRICE$4);
+                }
+                target.setDoubleValue(price);
+            }
+        }
+        
+        /**
+         * Sets (as xml) the "Price" element
+         */
+        public void xsetPrice(org.apache.xmlbeans.XmlDouble price)
+        {
+            synchronized (monitor())
+            {
+                check_orphaned();
+                org.apache.xmlbeans.XmlDouble target = null;
+                target = (org.apache.xmlbeans.XmlDouble)get_store().find_element_user(PRICE$4, 0);
+                if (target == null)
+                {
+                    target = (org.apache.xmlbeans.XmlDouble)get_store().add_element_user(PRICE$4);
+                }
+                target.set(price);
+            }
+        }
+        
+        /**
          * Gets the "Temperature" element
          */
         public org.wsdmdemo.service.weatherStation.TemperatureMetricType getTemperature()
@@ -171,7 +329,7 @@
             {
                 check_orphaned();
                 org.wsdmdemo.service.weatherStation.TemperatureMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.TemperatureMetricType)get_store().find_element_user(TEMPERATURE$2, 0);
+                target = (org.wsdmdemo.service.weatherStation.TemperatureMetricType)get_store().find_element_user(TEMPERATURE$6, 0);
                 if (target == null)
                 {
                     return null;
@@ -189,10 +347,10 @@
             {
                 check_orphaned();
                 org.wsdmdemo.service.weatherStation.TemperatureMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.TemperatureMetricType)get_store().find_element_user(TEMPERATURE$2, 0);
+                target = (org.wsdmdemo.service.weatherStation.TemperatureMetricType)get_store().find_element_user(TEMPERATURE$6, 0);
                 if (target == null)
                 {
-                    target = (org.wsdmdemo.service.weatherStation.TemperatureMetricType)get_store().add_element_user(TEMPERATURE$2);
+                    target = (org.wsdmdemo.service.weatherStation.TemperatureMetricType)get_store().add_element_user(TEMPERATURE$6);
                 }
                 target.set(temperature);
             }
@@ -207,7 +365,7 @@
             {
                 check_orphaned();
                 org.wsdmdemo.service.weatherStation.TemperatureMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.TemperatureMetricType)get_store().add_element_user(TEMPERATURE$2);
+                target = (org.wsdmdemo.service.weatherStation.TemperatureMetricType)get_store().add_element_user(TEMPERATURE$6);
                 return target;
             }
         }
@@ -221,7 +379,7 @@
             {
                 check_orphaned();
                 org.wsdmdemo.service.weatherStation.HumidityMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.HumidityMetricType)get_store().find_element_user(HUMIDITY$4, 0);
+                target = (org.wsdmdemo.service.weatherStation.HumidityMetricType)get_store().find_element_user(HUMIDITY$8, 0);
                 if (target == null)
                 {
                     return null;
@@ -239,10 +397,10 @@
             {
                 check_orphaned();
                 org.wsdmdemo.service.weatherStation.HumidityMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.HumidityMetricType)get_store().find_element_user(HUMIDITY$4, 0);
+                target = (org.wsdmdemo.service.weatherStation.HumidityMetricType)get_store().find_element_user(HUMIDITY$8, 0);
                 if (target == null)
                 {
-                    target = (org.wsdmdemo.service.weatherStation.HumidityMetricType)get_store().add_element_user(HUMIDITY$4);
+                    target = (org.wsdmdemo.service.weatherStation.HumidityMetricType)get_store().add_element_user(HUMIDITY$8);
                 }
                 target.set(humidity);
             }
@@ -257,7 +415,7 @@
             {
                 check_orphaned();
                 org.wsdmdemo.service.weatherStation.HumidityMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.HumidityMetricType)get_store().add_element_user(HUMIDITY$4);
+                target = (org.wsdmdemo.service.weatherStation.HumidityMetricType)get_store().add_element_user(HUMIDITY$8);
                 return target;
             }
         }
@@ -271,7 +429,7 @@
             {
                 check_orphaned();
                 org.wsdmdemo.service.weatherStation.VisibilityMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.VisibilityMetricType)get_store().find_element_user(VISIBILITY$6, 0);
+                target = (org.wsdmdemo.service.weatherStation.VisibilityMetricType)get_store().find_element_user(VISIBILITY$10, 0);
                 if (target == null)
                 {
                     return null;
@@ -289,10 +447,10 @@
             {
                 check_orphaned();
                 org.wsdmdemo.service.weatherStation.VisibilityMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.VisibilityMetricType)get_store().find_element_user(VISIBILITY$6, 0);
+                target = (org.wsdmdemo.service.weatherStation.VisibilityMetricType)get_store().find_element_user(VISIBILITY$10, 0);
                 if (target == null)
                 {
-                    target = (org.wsdmdemo.service.weatherStation.VisibilityMetricType)get_store().add_element_user(VISIBILITY$6);
+                    target = (org.wsdmdemo.service.weatherStation.VisibilityMetricType)get_store().add_element_user(VISIBILITY$10);
                 }
                 target.set(visibility);
             }
@@ -307,7 +465,7 @@
             {
                 check_orphaned();
                 org.wsdmdemo.service.weatherStation.VisibilityMetricType target = null;
-                target = (org.wsdmdemo.service.weatherStation.VisibilityMetricType)get_store().add_element_user(VISIBILITY$6);
+                target = (org.wsdmdemo.service.weatherStation.VisibilityMetricType)get_store().add_element_user(VISIBILITY$10);
                 return target;
             }
         }
@@ -321,7 +479,7 @@
             {
                 check_orphaned();
                 java.util.List targetList = new java.util.ArrayList();
-                get_store().find_all_element_users(TOPIC$8, targetList);
+                get_store().find_all_element_users(TOPIC$12, targetList);
                 org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType[] result = new org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType[targetList.size()];
                 targetList.toArray(result);
                 return result;
@@ -337,7 +495,7 @@
             {
                 check_orphaned();
                 org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType target = null;
-                target = (org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType)get_store().find_element_user(TOPIC$8, i);
+                target = (org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType)get_store().find_element_user(TOPIC$12, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -354,7 +512,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                return get_store().count_elements(TOPIC$8);
+                return get_store().count_elements(TOPIC$12);
             }
         }
         
@@ -366,7 +524,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                arraySetterHelper(topicArray, TOPIC$8);
+                arraySetterHelper(topicArray, TOPIC$12);
             }
         }
         
@@ -379,7 +537,7 @@
             {
                 check_orphaned();
                 org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType target = null;
-                target = (org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType)get_store().find_element_user(TOPIC$8, i);
+                target = (org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType)get_store().find_element_user(TOPIC$12, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -397,7 +555,7 @@
             {
                 check_orphaned();
                 org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType target = null;
-                target = (org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType)get_store().insert_element_user(TOPIC$8, i);
+                target = (org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType)get_store().insert_element_user(TOPIC$12, i);
                 return target;
             }
         }
@@ -411,7 +569,7 @@
             {
                 check_orphaned();
                 org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType target = null;
-                target = (org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType)get_store().add_element_user(TOPIC$8);
+                target = (org.oasisOpen.docs.wsn.x2004.x06.wsnWSBaseNotification12Draft01.TopicExpressionType)get_store().add_element_user(TOPIC$12);
                 return target;
             }
         }
@@ -424,7 +582,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                get_store().remove_element(TOPIC$8, i);
+                get_store().remove_element(TOPIC$12, i);
             }
         }
         
@@ -437,7 +595,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(FIXEDTOPICSET$10, 0);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(FIXEDTOPICSET$14, 0);
                 if (target == null)
                 {
                     return false;
@@ -455,7 +613,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlBoolean target = null;
-                target = (org.apache.xmlbeans.XmlBoolean)get_store().find_element_user(FIXEDTOPICSET$10, 0);
+                target = (org.apache.xmlbeans.XmlBoolean)get_store().find_element_user(FIXEDTOPICSET$14, 0);
                 return target;
             }
         }
@@ -469,10 +627,10 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(FIXEDTOPICSET$10, 0);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(FIXEDTOPICSET$14, 0);
                 if (target == null)
                 {
-                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(FIXEDTOPICSET$10);
+                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(FIXEDTOPICSET$14);
                 }
                 target.setBooleanValue(fixedTopicSet);
             }
@@ -487,10 +645,10 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlBoolean target = null;
-                target = (org.apache.xmlbeans.XmlBoolean)get_store().find_element_user(FIXEDTOPICSET$10, 0);
+                target = (org.apache.xmlbeans.XmlBoolean)get_store().find_element_user(FIXEDTOPICSET$14, 0);
                 if (target == null)
                 {
-                    target = (org.apache.xmlbeans.XmlBoolean)get_store().add_element_user(FIXEDTOPICSET$10);
+                    target = (org.apache.xmlbeans.XmlBoolean)get_store().add_element_user(FIXEDTOPICSET$14);
                 }
                 target.set(fixedTopicSet);
             }
@@ -505,7 +663,7 @@
             {
                 check_orphaned();
                 java.util.List targetList = new java.util.ArrayList();
-                get_store().find_all_element_users(TOPICEXPRESSIONDIALECTS$12, targetList);
+                get_store().find_all_element_users(TOPICEXPRESSIONDIALECTS$16, targetList);
                 java.lang.String[] result = new java.lang.String[targetList.size()];
                 for (int i = 0, len = targetList.size() ; i < len ; i++)
                     result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getStringValue();
@@ -522,7 +680,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(TOPICEXPRESSIONDIALECTS$12, i);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(TOPICEXPRESSIONDIALECTS$16, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -540,7 +698,7 @@
             {
                 check_orphaned();
                 java.util.List targetList = new java.util.ArrayList();
-                get_store().find_all_element_users(TOPICEXPRESSIONDIALECTS$12, targetList);
+                get_store().find_all_element_users(TOPICEXPRESSIONDIALECTS$16, targetList);
                 org.apache.xmlbeans.XmlAnyURI[] result = new org.apache.xmlbeans.XmlAnyURI[targetList.size()];
                 targetList.toArray(result);
                 return result;
@@ -556,7 +714,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlAnyURI target = null;
-                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(TOPICEXPRESSIONDIALECTS$12, i);
+                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(TOPICEXPRESSIONDIALECTS$16, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -573,7 +731,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                return get_store().count_elements(TOPICEXPRESSIONDIALECTS$12);
+                return get_store().count_elements(TOPICEXPRESSIONDIALECTS$16);
             }
         }
         
@@ -585,7 +743,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                arraySetterHelper(topicExpressionDialectsArray, TOPICEXPRESSIONDIALECTS$12);
+                arraySetterHelper(topicExpressionDialectsArray, TOPICEXPRESSIONDIALECTS$16);
             }
         }
         
@@ -598,7 +756,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(TOPICEXPRESSIONDIALECTS$12, i);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(TOPICEXPRESSIONDIALECTS$16, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -615,7 +773,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                arraySetterHelper(topicExpressionDialectsArray, TOPICEXPRESSIONDIALECTS$12);
+                arraySetterHelper(topicExpressionDialectsArray, TOPICEXPRESSIONDIALECTS$16);
             }
         }
         
@@ -628,7 +786,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlAnyURI target = null;
-                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(TOPICEXPRESSIONDIALECTS$12, i);
+                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(TOPICEXPRESSIONDIALECTS$16, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -646,7 +804,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = 
-                    (org.apache.xmlbeans.SimpleValue)get_store().insert_element_user(TOPICEXPRESSIONDIALECTS$12, i);
+                    (org.apache.xmlbeans.SimpleValue)get_store().insert_element_user(TOPICEXPRESSIONDIALECTS$16, i);
                 target.setStringValue(topicExpressionDialects);
             }
         }
@@ -660,7 +818,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(TOPICEXPRESSIONDIALECTS$12);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(TOPICEXPRESSIONDIALECTS$16);
                 target.setStringValue(topicExpressionDialects);
             }
         }
@@ -674,7 +832,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlAnyURI target = null;
-                target = (org.apache.xmlbeans.XmlAnyURI)get_store().insert_element_user(TOPICEXPRESSIONDIALECTS$12, i);
+                target = (org.apache.xmlbeans.XmlAnyURI)get_store().insert_element_user(TOPICEXPRESSIONDIALECTS$16, i);
                 return target;
             }
         }
@@ -688,7 +846,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlAnyURI target = null;
-                target = (org.apache.xmlbeans.XmlAnyURI)get_store().add_element_user(TOPICEXPRESSIONDIALECTS$12);
+                target = (org.apache.xmlbeans.XmlAnyURI)get_store().add_element_user(TOPICEXPRESSIONDIALECTS$16);
                 return target;
             }
         }
@@ -701,7 +859,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                get_store().remove_element(TOPICEXPRESSIONDIALECTS$12, i);
+                get_store().remove_element(TOPICEXPRESSIONDIALECTS$16, i);
             }
         }
         
@@ -714,7 +872,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(RESOURCEID$14, 0);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(RESOURCEID$18, 0);
                 if (target == null)
                 {
                     return null;
@@ -732,7 +890,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlAnyURI target = null;
-                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(RESOURCEID$14, 0);
+                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(RESOURCEID$18, 0);
                 return target;
             }
         }
@@ -746,10 +904,10 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(RESOURCEID$14, 0);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(RESOURCEID$18, 0);
                 if (target == null)
                 {
-                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(RESOURCEID$14);
+                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(RESOURCEID$18);
                 }
                 target.setStringValue(resourceId);
             }
@@ -764,10 +922,10 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlAnyURI target = null;
-                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(RESOURCEID$14, 0);
+                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(RESOURCEID$18, 0);
                 if (target == null)
                 {
-                    target = (org.apache.xmlbeans.XmlAnyURI)get_store().add_element_user(RESOURCEID$14);
+                    target = (org.apache.xmlbeans.XmlAnyURI)get_store().add_element_user(RESOURCEID$18);
                 }
                 target.set(resourceId);
             }
@@ -782,7 +940,7 @@
             {
                 check_orphaned();
                 java.util.List targetList = new java.util.ArrayList();
-                get_store().find_all_element_users(MANAGEABILITYCAPABILITY$16, targetList);
+                get_store().find_all_element_users(MANAGEABILITYCAPABILITY$20, targetList);
                 java.lang.String[] result = new java.lang.String[targetList.size()];
                 for (int i = 0, len = targetList.size() ; i < len ; i++)
                     result[i] = ((org.apache.xmlbeans.SimpleValue)targetList.get(i)).getStringValue();
@@ -799,7 +957,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(MANAGEABILITYCAPABILITY$16, i);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(MANAGEABILITYCAPABILITY$20, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -817,7 +975,7 @@
             {
                 check_orphaned();
                 java.util.List targetList = new java.util.ArrayList();
-                get_store().find_all_element_users(MANAGEABILITYCAPABILITY$16, targetList);
+                get_store().find_all_element_users(MANAGEABILITYCAPABILITY$20, targetList);
                 org.apache.xmlbeans.XmlAnyURI[] result = new org.apache.xmlbeans.XmlAnyURI[targetList.size()];
                 targetList.toArray(result);
                 return result;
@@ -833,7 +991,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlAnyURI target = null;
-                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(MANAGEABILITYCAPABILITY$16, i);
+                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(MANAGEABILITYCAPABILITY$20, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -850,7 +1008,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                return get_store().count_elements(MANAGEABILITYCAPABILITY$16);
+                return get_store().count_elements(MANAGEABILITYCAPABILITY$20);
             }
         }
         
@@ -862,7 +1020,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                arraySetterHelper(manageabilityCapabilityArray, MANAGEABILITYCAPABILITY$16);
+                arraySetterHelper(manageabilityCapabilityArray, MANAGEABILITYCAPABILITY$20);
             }
         }
         
@@ -875,7 +1033,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(MANAGEABILITYCAPABILITY$16, i);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(MANAGEABILITYCAPABILITY$20, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -892,7 +1050,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                arraySetterHelper(manageabilityCapabilityArray, MANAGEABILITYCAPABILITY$16);
+                arraySetterHelper(manageabilityCapabilityArray, MANAGEABILITYCAPABILITY$20);
             }
         }
         
@@ -905,7 +1063,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlAnyURI target = null;
-                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(MANAGEABILITYCAPABILITY$16, i);
+                target = (org.apache.xmlbeans.XmlAnyURI)get_store().find_element_user(MANAGEABILITYCAPABILITY$20, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -923,7 +1081,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = 
-                    (org.apache.xmlbeans.SimpleValue)get_store().insert_element_user(MANAGEABILITYCAPABILITY$16, i);
+                    (org.apache.xmlbeans.SimpleValue)get_store().insert_element_user(MANAGEABILITYCAPABILITY$20, i);
                 target.setStringValue(manageabilityCapability);
             }
         }
@@ -937,7 +1095,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(MANAGEABILITYCAPABILITY$16);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(MANAGEABILITYCAPABILITY$20);
                 target.setStringValue(manageabilityCapability);
             }
         }
@@ -951,7 +1109,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlAnyURI target = null;
-                target = (org.apache.xmlbeans.XmlAnyURI)get_store().insert_element_user(MANAGEABILITYCAPABILITY$16, i);
+                target = (org.apache.xmlbeans.XmlAnyURI)get_store().insert_element_user(MANAGEABILITYCAPABILITY$20, i);
                 return target;
             }
         }
@@ -965,7 +1123,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlAnyURI target = null;
-                target = (org.apache.xmlbeans.XmlAnyURI)get_store().add_element_user(MANAGEABILITYCAPABILITY$16);
+                target = (org.apache.xmlbeans.XmlAnyURI)get_store().add_element_user(MANAGEABILITYCAPABILITY$20);
                 return target;
             }
         }
@@ -978,7 +1136,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                get_store().remove_element(MANAGEABILITYCAPABILITY$16, i);
+                get_store().remove_element(MANAGEABILITYCAPABILITY$20, i);
             }
         }
         
@@ -991,7 +1149,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(CURRENTTIME$18, 0);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(CURRENTTIME$22, 0);
                 if (target == null)
                 {
                     return null;
@@ -1009,7 +1167,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlDateTime target = null;
-                target = (org.apache.xmlbeans.XmlDateTime)get_store().find_element_user(CURRENTTIME$18, 0);
+                target = (org.apache.xmlbeans.XmlDateTime)get_store().find_element_user(CURRENTTIME$22, 0);
                 return target;
             }
         }
@@ -1023,10 +1181,10 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(CURRENTTIME$18, 0);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(CURRENTTIME$22, 0);
                 if (target == null)
                 {
-                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(CURRENTTIME$18);
+                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(CURRENTTIME$22);
                 }
                 target.setCalendarValue(currentTime);
             }
@@ -1041,10 +1199,10 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.XmlDateTime target = null;
-                target = (org.apache.xmlbeans.XmlDateTime)get_store().find_element_user(CURRENTTIME$18, 0);
+                target = (org.apache.xmlbeans.XmlDateTime)get_store().find_element_user(CURRENTTIME$22, 0);
                 if (target == null)
                 {
-                    target = (org.apache.xmlbeans.XmlDateTime)get_store().add_element_user(CURRENTTIME$18);
+                    target = (org.apache.xmlbeans.XmlDateTime)get_store().add_element_user(CURRENTTIME$22);
                 }
                 target.set(currentTime);
             }
@@ -1059,7 +1217,7 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(OPERATIONALSTATUS$20, 0);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(OPERATIONALSTATUS$24, 0);
                 if (target == null)
                 {
                     return null;
@@ -1077,7 +1235,7 @@
             {
                 check_orphaned();
                 org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument.OperationalStatus target = null;
-                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument.OperationalStatus)get_store().find_element_user(OPERATIONALSTATUS$20, 0);
+                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument.OperationalStatus)get_store().find_element_user(OPERATIONALSTATUS$24, 0);
                 return target;
             }
         }
@@ -1091,10 +1249,10 @@
             {
                 check_orphaned();
                 org.apache.xmlbeans.SimpleValue target = null;
-                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(OPERATIONALSTATUS$20, 0);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(OPERATIONALSTATUS$24, 0);
                 if (target == null)
                 {
-                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(OPERATIONALSTATUS$20);
+                    target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(OPERATIONALSTATUS$24);
                 }
                 target.setEnumValue(operationalStatus);
             }
@@ -1109,10 +1267,10 @@
             {
                 check_orphaned();
                 org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument.OperationalStatus target = null;
-                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument.OperationalStatus)get_store().find_element_user(OPERATIONALSTATUS$20, 0);
+                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument.OperationalStatus)get_store().find_element_user(OPERATIONALSTATUS$24, 0);
                 if (target == null)
                 {
-                    target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument.OperationalStatus)get_store().add_element_user(OPERATIONALSTATUS$20);
+                    target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument.OperationalStatus)get_store().add_element_user(OPERATIONALSTATUS$24);
                 }
                 target.set(operationalStatus);
             }
@@ -1127,7 +1285,7 @@
             {
                 check_orphaned();
                 java.util.List targetList = new java.util.ArrayList();
-                get_store().find_all_element_users(RELATIONSHIP$22, targetList);
+                get_store().find_all_element_users(RELATIONSHIP$26, targetList);
                 org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType[] result = new org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType[targetList.size()];
                 targetList.toArray(result);
                 return result;
@@ -1143,7 +1301,7 @@
             {
                 check_orphaned();
                 org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType target = null;
-                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType)get_store().find_element_user(RELATIONSHIP$22, i);
+                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType)get_store().find_element_user(RELATIONSHIP$26, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -1160,7 +1318,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                return get_store().count_elements(RELATIONSHIP$22);
+                return get_store().count_elements(RELATIONSHIP$26);
             }
         }
         
@@ -1172,7 +1330,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                arraySetterHelper(relationshipArray, RELATIONSHIP$22);
+                arraySetterHelper(relationshipArray, RELATIONSHIP$26);
             }
         }
         
@@ -1185,7 +1343,7 @@
             {
                 check_orphaned();
                 org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType target = null;
-                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType)get_store().find_element_user(RELATIONSHIP$22, i);
+                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType)get_store().find_element_user(RELATIONSHIP$26, i);
                 if (target == null)
                 {
                     throw new IndexOutOfBoundsException();
@@ -1203,7 +1361,7 @@
             {
                 check_orphaned();
                 org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType target = null;
-                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType)get_store().insert_element_user(RELATIONSHIP$22, i);
+                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType)get_store().insert_element_user(RELATIONSHIP$26, i);
                 return target;
             }
         }
@@ -1217,7 +1375,7 @@
             {
                 check_orphaned();
                 org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType target = null;
-                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType)get_store().add_element_user(RELATIONSHIP$22);
+                target = (org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.RelationshipType)get_store().add_element_user(RELATIONSHIP$26);
                 return target;
             }
         }
@@ -1230,7 +1388,7 @@
             synchronized (monitor())
             {
                 check_orphaned();
-                get_store().remove_element(RELATIONSHIP$22, i);
+                get_store().remove_element(RELATIONSHIP$26, i);
             }
         }
     }

Modified: incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/AddWeatherStationDocument.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/AddWeatherStationDocument.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/AddWeatherStationDocument.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/AddWeatherStationDocument.java Tue May 31 07:29:42 2005
@@ -16,7 +16,7 @@
  */
 public interface AddWeatherStationDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s69D01B8DFD540216FFB13E59A0385877.TypeSystemHolder.typeSystem.resolveHandle("addweatherstation9ceadoctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s9E7FC4E641C5BF4F9C2058147CCC2D74.TypeSystemHolder.typeSystem.resolveHandle("addweatherstation9ceadoctype");
     
     /**
      * Gets the "AddWeatherStation" element
@@ -40,7 +40,7 @@
      */
     public interface AddWeatherStation extends org.apache.xmlbeans.XmlObject
     {
-        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s69D01B8DFD540216FFB13E59A0385877.TypeSystemHolder.typeSystem.resolveHandle("addweatherstationce57elemtype");
+        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s9E7FC4E641C5BF4F9C2058147CCC2D74.TypeSystemHolder.typeSystem.resolveHandle("addweatherstationce57elemtype");
         
         /**
          * Gets the "EndpointReference" element

Modified: incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/AddWeatherStationResponseDocument.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/AddWeatherStationResponseDocument.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/AddWeatherStationResponseDocument.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/AddWeatherStationResponseDocument.java Tue May 31 07:29:42 2005
@@ -16,7 +16,7 @@
  */
 public interface AddWeatherStationResponseDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s69D01B8DFD540216FFB13E59A0385877.TypeSystemHolder.typeSystem.resolveHandle("addweatherstationresponsec74bdoctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s9E7FC4E641C5BF4F9C2058147CCC2D74.TypeSystemHolder.typeSystem.resolveHandle("addweatherstationresponsec74bdoctype");
     
     /**
      * Gets the "AddWeatherStationResponse" element
@@ -40,7 +40,7 @@
      */
     public interface AddWeatherStationResponse extends org.apache.xmlbeans.XmlObject
     {
-        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s69D01B8DFD540216FFB13E59A0385877.TypeSystemHolder.typeSystem.resolveHandle("addweatherstationresponse2999elemtype");
+        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s9E7FC4E641C5BF4F9C2058147CCC2D74.TypeSystemHolder.typeSystem.resolveHandle("addweatherstationresponse2999elemtype");
         
         /**
          * A factory class with static methods for creating instances

Modified: incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/RemoveWeatherStationDocument.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/RemoveWeatherStationDocument.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/RemoveWeatherStationDocument.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/RemoveWeatherStationDocument.java Tue May 31 07:29:42 2005
@@ -16,7 +16,7 @@
  */
 public interface RemoveWeatherStationDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s69D01B8DFD540216FFB13E59A0385877.TypeSystemHolder.typeSystem.resolveHandle("removeweatherstation231fdoctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s9E7FC4E641C5BF4F9C2058147CCC2D74.TypeSystemHolder.typeSystem.resolveHandle("removeweatherstation231fdoctype");
     
     /**
      * Gets the "RemoveWeatherStation" element
@@ -40,7 +40,7 @@
      */
     public interface RemoveWeatherStation extends org.apache.xmlbeans.XmlObject
     {
-        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s69D01B8DFD540216FFB13E59A0385877.TypeSystemHolder.typeSystem.resolveHandle("removeweatherstationae1felemtype");
+        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s9E7FC4E641C5BF4F9C2058147CCC2D74.TypeSystemHolder.typeSystem.resolveHandle("removeweatherstationae1felemtype");
         
         /**
          * Gets the "ResourceId" element

Modified: incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/RemoveWeatherStationResponseDocument.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/RemoveWeatherStationResponseDocument.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/RemoveWeatherStationResponseDocument.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/RemoveWeatherStationResponseDocument.java Tue May 31 07:29:42 2005
@@ -16,7 +16,7 @@
  */
 public interface RemoveWeatherStationResponseDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s69D01B8DFD540216FFB13E59A0385877.TypeSystemHolder.typeSystem.resolveHandle("removeweatherstationresponse4880doctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s9E7FC4E641C5BF4F9C2058147CCC2D74.TypeSystemHolder.typeSystem.resolveHandle("removeweatherstationresponse4880doctype");
     
     /**
      * Gets the "RemoveWeatherStationResponse" element
@@ -40,7 +40,7 @@
      */
     public interface RemoveWeatherStationResponse extends org.apache.xmlbeans.XmlObject
     {
-        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s69D01B8DFD540216FFB13E59A0385877.TypeSystemHolder.typeSystem.resolveHandle("removeweatherstationresponse30ffelemtype");
+        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s9E7FC4E641C5BF4F9C2058147CCC2D74.TypeSystemHolder.typeSystem.resolveHandle("removeweatherstationresponse30ffelemtype");
         
         /**
          * A factory class with static methods for creating instances

Modified: incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/WeatherStationDirectoryResourcePropertiesDocument.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/WeatherStationDirectoryResourcePropertiesDocument.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/WeatherStationDirectoryResourcePropertiesDocument.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStationDir/WeatherStationDirectoryResourcePropertiesDocument.java Tue May 31 07:29:42 2005
@@ -16,7 +16,7 @@
  */
 public interface WeatherStationDirectoryResourcePropertiesDocument extends org.apache.xmlbeans.XmlObject
 {
-    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s69D01B8DFD540216FFB13E59A0385877.TypeSystemHolder.typeSystem.resolveHandle("weatherstationdirectoryresourceproperties96b7doctype");
+    public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s9E7FC4E641C5BF4F9C2058147CCC2D74.TypeSystemHolder.typeSystem.resolveHandle("weatherstationdirectoryresourceproperties96b7doctype");
     
     /**
      * Gets the "WeatherStationDirectoryResourceProperties" element
@@ -40,7 +40,7 @@
      */
     public interface WeatherStationDirectoryResourceProperties extends org.apache.xmlbeans.XmlObject
     {
-        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s69D01B8DFD540216FFB13E59A0385877.TypeSystemHolder.typeSystem.resolveHandle("weatherstationdirectoryresourceproperties5871elemtype");
+        public static final org.apache.xmlbeans.SchemaType type = (org.apache.xmlbeans.SchemaType)schema.system.s9E7FC4E641C5BF4F9C2058147CCC2D74.TypeSystemHolder.typeSystem.resolveHandle("weatherstationdirectoryresourceproperties5871elemtype");
         
         /**
          * Gets array of all "Topic" elements

Modified: incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/AbstractWeather-client-configService.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/AbstractWeather-client-configService.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/AbstractWeather-client-configService.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/AbstractWeather-client-configService.java Tue May 31 07:29:42 2005
@@ -17,7 +17,7 @@
  * NOTE: This class is generated and is NOT meant to be modified.
  */
 public abstract class AbstractWeather-client-configService extends AbstractPortType
-    implements org.apache.ws.resource.handler.WsrfService, org.apache.ws.resource.properties.v2004_06.porttype.GetMultipleResourcePropertiesPortType, org.apache.ws.resource.properties.v2004_06.porttype.GetResourcePropertyPortType, org.apache.ws.notification.base.v2004_06.porttype.NotificationProducerPortType, org.apache.ws.muws.v1_0.capability.RelationshipsCapability {
+    implements org.apache.ws.resource.handler.WsrfService, org.apache.ws.resource.properties.v2004_06.porttype.SetResourcePropertiesPortType, org.apache.ws.resource.properties.v2004_06.porttype.GetMultipleResourcePropertiesPortType, org.apache.ws.resource.properties.v2004_06.porttype.GetResourcePropertyPortType, org.apache.ws.notification.base.v2004_06.porttype.NotificationProducerPortType, org.apache.ws.muws.v1_0.capability.RelationshipsCapability {
 
    public static final String TARGET_NSURI = "http://wsdmdemo.org/service/weather-client-config";
    public static final String TARGET_NSPREFIX = "weather-client-config";
@@ -71,7 +71,6 @@
    public void init(  )
    {
       m_methodNameMap    = new ServiceSoapMethodNameMap( getResourceContext(  ) );
-      m_methodNameMap.addMapping( javax.xml.namespace.QName.valueOf("{http://wsdmdemo.org/service/weather-client-config}SetWeatherStation") , "SetWeatherStation" );
       m_isInitialized      = true;
    }
    
@@ -84,6 +83,18 @@
    protected final boolean isInitialized(  )
    {
          return m_isInitialized;
+   }
+
+   /**
+    * DOCUMENT_ME
+    *
+    * @param requestDoc DOCUMENT_ME
+    *
+    * @return DOCUMENT_ME
+    */
+   public org.oasisOpen.docs.wsrf.x2004.x06.wsrfWSResourceProperties12Draft01.SetResourcePropertiesResponseDocument setResourceProperties( org.oasisOpen.docs.wsrf.x2004.x06.wsrfWSResourceProperties12Draft01.SetResourcePropertiesDocument requestDoc )
+   {
+      return new org.apache.ws.resource.properties.v2004_06.porttype.impl.SetResourcePropertiesPortTypeImpl( getResourceContext(  ) ).setResourceProperties( requestDoc );
    }
 
    /**

Modified: incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configCustomOperationsPortType.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configCustomOperationsPortType.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configCustomOperationsPortType.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configCustomOperationsPortType.java Tue May 31 07:29:42 2005
@@ -12,6 +12,5 @@
 public interface Weather-client-configCustomOperationsPortType
 {
    
-      public org.wsdmdemo.service.weatherClientConfig.SetWeatherStationResponseDocument SetWeatherStation( org.wsdmdemo.service.weatherClientConfig.SetWeatherStationDocument requestDoc ) throws org.wsdmdemo.service.weatherClientConfig.SetFailedFaultException ;       
    
 }

Modified: incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configPropertyQNames.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configPropertyQNames.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configPropertyQNames.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configPropertyQNames.java Tue May 31 07:29:42 2005
@@ -17,12 +17,16 @@
             new QName( "http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part1.xsd", "ManageabilityCapability", "muws-p1-xs");        
             QName TOPICEXPRESSIONDIALECTS =
             new QName( "http://docs.oasis-open.org/wsn/2004/06/wsn-WS-BaseNotification-1.2-draft-01.xsd", "TopicExpressionDialects", "wsnt");        
+            QName WEATHERSTATIONREFERENCE =
+            new QName( "http://wsdmdemo.org/service/weather-client-config", "WeatherStationReference", "tns");        
             QName RESOURCEID =
             new QName( "http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part1.xsd", "ResourceId", "muws-p1-xs");        
             QName FIXEDTOPICSET =
             new QName( "http://docs.oasis-open.org/wsn/2004/06/wsn-WS-BaseNotification-1.2-draft-01.xsd", "FixedTopicSet", "wsnt");        
             QName OPERATIONALSTATUS =
             new QName( "http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd", "OperationalStatus", "muws-p2-xs");        
+            QName WEATHERDATAREFRESHINTERVAL =
+            new QName( "http://wsdmdemo.org/service/weather-client-config", "WeatherDataRefreshInterval", "tns");        
             QName RELATIONSHIP =
             new QName( "http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd", "Relationship", "muws-p2-xs");        
             QName TOPIC =

Modified: incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configResource.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configResource.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configResource.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configResource.java Tue May 31 07:29:42 2005
@@ -40,6 +40,14 @@
 		resourceProperty.add(prop_manageabilitycapability);
 	
 	
+		// init the {http://wsdmdemo.org/service/weather-client-config}WeatherStationReference Resource Property
+		resourceProperty = resourcePropertySet.get(Weather-client-configPropertyQNames.WEATHERSTATIONREFERENCE);
+		org.wsdmdemo.service.weatherClientConfig.WeatherStationReferenceDocument prop_weatherstationreference = org.wsdmdemo.service.weatherClientConfig.WeatherStationReferenceDocument.Factory.newInstance();
+		// TODO: Initialize the prop_weatherstationreference by calling its operations.
+		//also could call resourceProperty.setCallback(...); to add a custom callback object for this property
+		resourceProperty.add(prop_weatherstationreference);
+	
+	
 		// init the {http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part1.xsd}ResourceId Resource Property
 		resourceProperty = resourcePropertySet.get(Weather-client-configPropertyQNames.RESOURCEID);
 		org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart1.ResourceIdDocument prop_resourceid = org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart1.ResourceIdDocument.Factory.newInstance();
@@ -48,6 +56,14 @@
 		resourceProperty.add(prop_resourceid);
 	
 	
+		// init the {http://wsdmdemo.org/service/weather-client-config}WeatherDataRefreshInterval Resource Property
+		resourceProperty = resourcePropertySet.get(Weather-client-configPropertyQNames.WEATHERDATAREFRESHINTERVAL);
+		org.wsdmdemo.service.weatherClientConfig.WeatherDataRefreshIntervalDocument prop_weatherdatarefreshinterval = org.wsdmdemo.service.weatherClientConfig.WeatherDataRefreshIntervalDocument.Factory.newInstance();
+		// TODO: Initialize the prop_weatherdatarefreshinterval by calling its operations.
+		//also could call resourceProperty.setCallback(...); to add a custom callback object for this property
+		resourceProperty.add(prop_weatherdatarefreshinterval);
+	
+	
 		// init the {http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd}OperationalStatus Resource Property
 		resourceProperty = resourcePropertySet.get(Weather-client-configPropertyQNames.OPERATIONALSTATUS);
 		org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument prop_operationalstatus = org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument.Factory.newInstance();
@@ -75,6 +91,20 @@
 			
 			
 
+   /**
+    * This method call will make all resource properties be exposed
+    * as Topics.  If you would like to change that behaviour you can 
+    * call TopicUtils.addResourcePropertyValueChangeTopic for each
+    * Topic you'd like to expose property change notifications for.
+    */
+   try
+   {
+   org.apache.ws.notification.topics.util.TopicUtils.addResourcePropertyValueChangeTopics( getResourcePropertySet(), getTopicSpaceSet() ); 
+   }
+   catch (Exception e)
+   {
+	throw new javax.xml.rpc.JAXRPCException("Unable to init the ResourceProperty Changed topics. Cause: " + e.getLocalizedMessage(), e);
+   }  
                 
             /**
      * Initializes the Topic, TopicExpressionDialects and FixedTopicSet resource properties

Modified: incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configService.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configService.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configService.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherClientConfig/Weather-client-configService.java Tue May 31 07:29:42 2005
@@ -52,14 +52,4 @@
    }
    
       
-   public org.wsdmdemo.service.weatherClientConfig.SetWeatherStationResponseDocument SetWeatherStation( org.wsdmdemo.service.weatherClientConfig.SetWeatherStationDocument requestDoc ) throws org.wsdmdemo.service.weatherClientConfig.SetFailedFaultException
-   {              
-     	org.wsdmdemo.service.weatherClientConfig.SetWeatherStationResponseDocument responseDocument = org.wsdmdemo.service.weatherClientConfig.SetWeatherStationResponseDocument.Factory.newInstance();	
-     	org.wsdmdemo.service.weatherClientConfig.SetWeatherStationResponseDocument.SetWeatherStationResponse  response = responseDocument.addNewSetWeatherStationResponse();
-     	//TODO implement method and populate the response object 
-     	return responseDocument;
-   }
-   
-   
-      
 }

Modified: incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherStation/Weather-stationPropertyQNames.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherStation/Weather-stationPropertyQNames.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherStation/Weather-stationPropertyQNames.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherStation/Weather-stationPropertyQNames.java Tue May 31 07:29:42 2005
@@ -13,26 +13,30 @@
 public interface Weather-stationPropertyQNames
 {
     
+            QName TEMPERATURE =
+            new QName( "http://wsdmdemo.org/service/weather-station", "Temperature", "tns");        
+            QName TOPICEXPRESSIONDIALECTS =
+            new QName( "http://docs.oasis-open.org/wsn/2004/06/wsn-WS-BaseNotification-1.2-draft-01.xsd", "TopicExpressionDialects", "wsnt");        
+            QName RESOURCEID =
+            new QName( "http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part1.xsd", "ResourceId", "muws-p1-xs");        
             QName VISIBILITY =
             new QName( "http://wsdmdemo.org/service/weather-station", "Visibility", "tns");        
             QName MANAGEABILITYCAPABILITY =
             new QName( "http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part1.xsd", "ManageabilityCapability", "muws-p1-xs");        
-            QName TEMPERATURE =
-            new QName( "http://wsdmdemo.org/service/weather-station", "Temperature", "tns");        
             QName HUMIDITY =
             new QName( "http://wsdmdemo.org/service/weather-station", "Humidity", "tns");        
-            QName TOPICEXPRESSIONDIALECTS =
-            new QName( "http://docs.oasis-open.org/wsn/2004/06/wsn-WS-BaseNotification-1.2-draft-01.xsd", "TopicExpressionDialects", "wsnt");        
             QName PRICE =
             new QName( "http://wsdmdemo.org/service/weather-station", "Price", "tns");        
-            QName RESOURCEID =
-            new QName( "http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part1.xsd", "ResourceId", "muws-p1-xs");        
-            QName FIXEDTOPICSET =
-            new QName( "http://docs.oasis-open.org/wsn/2004/06/wsn-WS-BaseNotification-1.2-draft-01.xsd", "FixedTopicSet", "wsnt");        
+            QName NAME =
+            new QName( "http://wsdmdemo.org/service/weather-station", "Name", "tns");        
             QName OPERATIONALSTATUS =
             new QName( "http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd", "OperationalStatus", "muws-p2-xs");        
+            QName FIXEDTOPICSET =
+            new QName( "http://docs.oasis-open.org/wsn/2004/06/wsn-WS-BaseNotification-1.2-draft-01.xsd", "FixedTopicSet", "wsnt");        
             QName CURRENTTIME =
             new QName( "http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd", "CurrentTime", "muws-p2-xs");        
+            QName OWNER =
+            new QName( "http://wsdmdemo.org/service/weather-station", "Owner", "tns");        
             QName RELATIONSHIP =
             new QName( "http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd", "Relationship", "muws-p2-xs");        
             QName TOPIC =

Modified: incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherStation/Weather-stationResource.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherStation/Weather-stationResource.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================
--- incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherStation/Weather-stationResource.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/java/org/wsdmdemo/service/weatherStation/Weather-stationResource.java Tue May 31 07:29:42 2005
@@ -80,12 +80,28 @@
 		resourceProperty.add(prop_price);
 	
 	
+		// init the {http://wsdmdemo.org/service/weather-station}Name Resource Property
+		resourceProperty = resourcePropertySet.get(Weather-stationPropertyQNames.NAME);
+		org.wsdmdemo.service.weatherStation.NameDocument prop_name = org.wsdmdemo.service.weatherStation.NameDocument.Factory.newInstance();
+		// TODO: Initialize the prop_name by calling its operations.
+		//also could call resourceProperty.setCallback(...); to add a custom callback object for this property
+		resourceProperty.add(prop_name);
+	
+	
 		// init the {http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd}OperationalStatus Resource Property
 		resourceProperty = resourcePropertySet.get(Weather-stationPropertyQNames.OPERATIONALSTATUS);
 		org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument prop_operationalstatus = org.oasisOpen.docs.wsdm.x2004.x12.muws.wsdmMuwsPart2.OperationalStatusDocument.Factory.newInstance();
 		// TODO: Initialize the prop_operationalstatus by calling its operations.
 		//also could call resourceProperty.setCallback(...); to add a custom callback object for this property
 		resourceProperty.add(prop_operationalstatus);
+	
+	
+		// init the {http://wsdmdemo.org/service/weather-station}Owner Resource Property
+		resourceProperty = resourcePropertySet.get(Weather-stationPropertyQNames.OWNER);
+		org.wsdmdemo.service.weatherStation.OwnerDocument prop_owner = org.wsdmdemo.service.weatherStation.OwnerDocument.Factory.newInstance();
+		// TODO: Initialize the prop_owner by calling its operations.
+		//also could call resourceProperty.setCallback(...); to add a custom callback object for this property
+		resourceProperty.add(prop_owner);
 	
 	
 		// init the {http://docs.oasis-open.org/wsdm/2004/12/muws/wsdm-muws-part2.xsd}Relationship Resource Property



---------------------------------------------------------------------
To unsubscribe, e-mail: muse-dev-unsubscribe@ws.apache.org
For additional commands, e-mail: muse-dev-help@ws.apache.org
--- incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStation/impl/PriceDocumentImpl.java (original)
+++ incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStation/impl/PriceDocumentImpl.java Tue May 31 07:29:42 2005
@@ -27,17 +27,31 @@
     /**
      * Gets the "Price" element
      */
-    public org.wsdmdemo.service.weatherStation.PriceMetricType getPrice()
+    public double getPrice()
     {
         synchronized (monitor())
         {
             check_orphaned();
-            org.wsdmdemo.service.weatherStation.PriceMetricType target = null;
-            target = (org.wsdmdemo.service.weatherStation.PriceMetricType)get_store().find_element_user(PRICE$0, 0);
+            org.apache.xmlbeans.SimpleValue target = null;
+            target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(PRICE$0, 0);
             if (target == null)
             {
-                return null;
+                return 0.0;
             }
+            return target.getDoubleValue();
+        }
+    }
+    
+    /**
+     * Gets (as xml) the "Price" element
+     */
+    public org.apache.xmlbeans.XmlDouble xgetPrice()
+    {
+        synchronized (monitor())
+        {
+            check_orphaned();
+            org.apache.xmlbeans.XmlDouble target = null;
+            target = (org.apache.xmlbeans.XmlDouble)get_store().find_element_user(PRICE$0, 0);
             return target;
         }
     }
@@ -45,32 +59,36 @@
     /**
      * Sets the "Price" element
      */
-    public void setPrice(org.wsdmdemo.service.weatherStation.PriceMetricType price)
+    public void setPrice(double price)
     {
         synchronized (monitor())
         {
             check_orphaned();
-            org.wsdmdemo.service.weatherStation.PriceMetricType target = null;
-            target = (org.wsdmdemo.service.weatherStation.PriceMetricType)get_store().find_element_user(PRICE$0, 0);
+            org.apache.xmlbeans.SimpleValue target = null;
+            target = (org.apache.xmlbeans.SimpleValue)get_store().find_element_user(PRICE$0, 0);
             if (target == null)
             {
-                target = (org.wsdmdemo.service.weatherStation.PriceMetricType)get_store().add_element_user(PRICE$0);
+                target = (org.apache.xmlbeans.SimpleValue)get_store().add_element_user(PRICE$0);
             }
-            target.set(price);
+            target.setDoubleValue(price);
         }
     }
     
     /**
      * Appends and returns a new empty "Price" element
      */
-    public org.wsdmdemo.service.weatherStation.PriceMetricType addNewPrice()
+    public void xsetPrice(org.apache.xmlbeans.XmlDouble price)
     {
         synchronized (monitor())
         {
             check_orphaned();
-            org.wsdmdemo.service.weatherStation.PriceMetricType target = null;
-            target = (org.wsdmdemo.service.weatherStation.PriceMetricType)get_store().add_element_user(PRICE$0);
-            return target;
+            org.apache.xmlbeans.XmlDouble target = null;
+            target = (org.apache.xmlbeans.XmlDouble)get_store().find_element_user(PRICE$0, 0);
+            if (target == null)
+            {
+                target = (org.apache.xmlbeans.XmlDouble)get_store().add_element_user(PRICE$0);
+            }
+            target.set(price);
         }
     }
 }
@@ -45,32 +59,36 @@
     
     /**
-     * Appends and returns a new empty "Price" element
+     * Sets (as xml) the "Price" element
      */

Modified: incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStation/impl/WeatherStationResourcePropertiesDocumentImpl.java
URL: http://svn.apache.org/viewcvs/incubator/muse/trunk/src/ieeedemo/src/.xmlbeans/src/org/wsdmdemo/service/weatherStation/impl/WeatherStationResourcePropertiesDocumentImpl.java?rev=179217&r1=179216&r2=179217&view=diff
==============================================================================